#
# spec file for package emacs-compat
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2024 Björn Bidar
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _name    compat

Name:           emacs-%{_name}
Version:        30.0.0.0
Release:        2.1
Summary:        COMPATibility Library for Emacs Lisp
License:        GPL-3.0-or-later
Group:          Productivity/Text/Editors
URL:            https://github.com/emacs-compat/compat
Source0:        %{_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  emacs-devel
BuildRequires:  emacs-nox
BuildRequires:  info
BuildRequires:  make
BuildRequires:  makeinfo
Requires:       emacs
Supplements:    emacs
%if 0%{?suse_version} <= 1600
Requires(post): %install_info_prereq
Requires(preun): %install_info_prereq
%endif
# PATCH-FEATURE-UPSTREAM install targets PR 30
Patch1:         0001-Add-install-target.patch
# # PATCH-FEATURE-UPSTREAM Fix Texinfo references PR 49
Patch2:         0002-compat.texi-Fix-references-to-Emacs-30.1-in-Support-.patch

%description
compat.el, the forwards-compatibility library for (GNU) Emacs Lisp, versions 24.4 and newer. The intended audience are package developers that are interested in using newer developments, without having to break compatibility.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%make_build

%install
%make_install
install -m 0644 compat-macs.el %{buildroot}%{_emacs_sitelispdir}

%check

%if 0%{?suse_version} >= 1600
%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{_name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{_name}.info.gz
%endif

%files
%doc README.md
%license COPYING
%{_emacs_sitelispdir}/%{_name}*.el*
%{_infodir}/%{_name}*

%changelog
* Thu Jan  9 2025 Dr. Werner Fink <werner@suse.de>
- Install also compat-mac.el as native compilation search for it
* Sat Aug  3 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Add back the install_info macro's for Leap, info triggers
  are not old enough for Leap
- Add patch to fix Texinfo references inside the manual:
  0002-compat.texi-Fix-references-to-Emacs-30.1-in-Support-.patch
* Sat Aug  3 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Remove use deprecated install_info macro's
- Rebase 0001-Add-install-target.patch against new upstream version
- Update to version 30.0.0.0:
  * compat-28: Mark =subr-native-elisp-p= as obsolete (renamed in Emacs 30).
  * compat-30: New function =char-to-name=.
  * compat-30: New function =obarray-clear=.
  * compat-30: New function =interpreted-function-p=.
  * compat-30: New function =primitive-function-p=.
  * compat-30: New function =closurep=.
  * compat-30: Add extended function =sort= with keyword arguments.
  * compat-30: New function =value<=.
  * compat-30: Add extended =copy-tree= with support for copying records with
    non-nil optional second argument.
  * compat-30: New macro =static-if=.
  * compat-30: New alias =drop=.
  * compat-30: New function =merge-ordered-lists=.
  * compat-30: New variables =completion-lazy-hilit= and =completion-lazy-hilit-fn=
    and new function =completion-lazy-hilit=.
  * compat-30: New function =require-with-check=.
  * compat-30: New functions =find-buffer= and =get-truename-buffer=.
  * compat-30: Add extended =completion-metadata-get= with support for
    =completion-category-overrides= and =completion-extra-properties=.
* Mon Mar 25 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 29.1.4.5:
  * Update NEWS.org
  * compat-tests: Fix compat-thing-at-mouse test
  * Use https links everywhere
  * compat.texi: Use @dfn{Extended Definitions}
  * NEWS: Mention addition of compat.el to Emacs
  * compat.texi: Update manual after the inclusion of compat.el in Emacs
  * compat-tests: Fix commentary linter warnings
  * compat-tests: Use should-equal
  * compat--maybe-require: Rename macro to reduce churn
* Mon Feb 26 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Depend on emacs-devel to make sure Emacs packaging macros are installed when not building with emacs-eln
* Wed Jan 31 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 29.1.4.4:
  * The maintainer field accepts only a single mail address
  * fix(compat.el): Package-Requires "seq" = 2.3 -> 2.23 (#31)
  * compat.texi: Fix typos
* Wed Sep 27 2023 Björn Bidar <bjorn.bidar@thaodan.de>
- Initial packaging for OpenSuSE
- Include patch to add install targets to upstream makefiles
- Compat 29.1.4.2
  * compat-28: Improve =make-separator-line= visuals on graphic displays
  * compat-28: Add =native-comp-available-p=, which always returns nil
  * compat-29: Add variable =lisp-directory=
